@@ -32,40 +32,14 @@ import fedmsg.config
 import fedmsg.consumers
 import fedmsg.encoding
 
+from common import load_config
+
 
 # Some constants used throughout the hub tests
 sleep_duration = 0.25
 secret = "secret_message"
 
 
-def load_config(name='fedmsg-test-config.py'):
-    here = os.path.sep.join(__file__.split(os.path.sep)[:-1])
-    test_config = os.path.sep.join([here, name])
-
-    config = fedmsg.config.load_config(
-        [],
-        "awesome",
-        filenames=[
-            test_config,
-        ],
-        invalidate_cache=True
-    )
-
-    # Enable all of our test consumers so they can do their thing.
-    config['test_consumer_enabled'] = True
-
-    # TODO -- this appears everywhere and should be encapsulated in a func
-    # Massage the fedmsg config into the moksha config.
-    config['zmq_subscribe_endpoints'] = ','.join(
-        ','.join(bunch) for bunch in config['endpoints'].values()
-    )
-    hub_name = "twisted.%s" % socket.gethostname()
-    config['zmq_publish_endpoints'] = ','.join(
-        config['endpoints'][hub_name]
-    )
-    return config
-
-
 # This used to raise a keyerror, but no longer.
 @raises(KeyError)
 def test_init_missing_endpoint():
